@@ -8,7 +8,11 @@ import {
   VACCINE_STATUS,
   VISIBILITY_STATUSES,
   REFERENCE_DATA_RELATION_TYPES,
+  SURVEY_TYPES,
   INJECTION_SITE_VALUES,
+  TASK_FREQUENCY_ACCEPTED_UNITS,
+  TASK_FREQUENCY_ACCEPTED_UNITS_TO_VALUE,
+  REFERENCE_TYPES,
 } from '@tamanu/constants';
 import config from 'config';
 import {
@@ -122,6 +126,14 @@ export const Location = Base.shape({
     .max(1, 'maxOccupancy above 1 is unimplemented'),
 });
 
+export const LocationGroup = Base.shape({
+  code: fieldTypes.code.required(),
+  name: fieldTypes.name.required(),
+  facilityId: yup.string().required(),
+  visibilityStatus,
+  isBookable: yup.boolean().default(false),
+});
+
 export const Permission = yup.object().shape({
   _yCell: yup.string().oneOf(['y', 'n'], 'permissions matrix must only use the letter y or n'), // validation-only, not stored in the database anywhere
   verb: yup.string().required(),
@@ -282,7 +294,7 @@ export const Survey = Base.shape({
   surveyType: yup
     .string()
     .required()
-    .oneOf(['programs', 'referral', 'obsolete', 'vitals']),
+    .oneOf(Object.values(SURVEY_TYPES)),
   isSensitive: yup.boolean().required(),
   visibilityStatus: yup
     .string()
@@ -357,8 +369,38 @@ export const UserFacility = yup.object().shape({
 });
 
 export const InvoiceProduct = yup.object().shape({
+  id: yup.string().required(),
   name: yup.string().required(),
-  price: yup.number().required(),
+  price: yup.number().when('id', {
+    is: (id) => id && id.startsWith(REFERENCE_TYPES.ADDITIONAL_INVOICE_PRODUCT),
+    then: yup.number().optional(),
+    otherwise: yup.number().required(),
+  }),
   discountable: yup.boolean().required(),
-  visibilityStatus
+  visibilityStatus,
+});
+
+export const UserDesignation = yup.object().shape({
+  userId: yup.string().required(),
+  designationId: yup.string().required(),
+});
+
+export const TaskTemplate = yup.object().shape({
+  id: yup.string().required(),
+  referenceDataId: yup.string().required(),
+  highPriority: yup.boolean().optional(),
+  frequencyValue: yup
+    .number()
+    .moreThan(0)
+    .optional(),
+  frequencyUnit: yup
+    .string()
+    .optional()
+    .transform(value => TASK_FREQUENCY_ACCEPTED_UNITS_TO_VALUE[value] || value)
+    .oneOf([...Object.values(TASK_FREQUENCY_ACCEPTED_UNITS), null]),
+});
+
+export const TaskTemplateDesignation = yup.object().shape({
+  taskTemplateId: yup.string().required(),
+  designationId: yup.string().required(),
 });
