@@ -1,6 +1,6 @@
 import { FHIR_INTERACTIONS } from '@tamanu/constants';
 import { resourcesThatCanDo } from '@tamanu/shared/utils/fhir/resources';
-import { sleepAsync } from '@tamanu/shared/utils/sleepAsync';
+import { sleepAsync } from '@tamanu/utils/sleepAsync';
 
 export async function resolver(_, { log, sequelize, models }) {
   await sleepAsync(3000); // sleep for 3 seconds to allow materialisation jobs to complete
