@@ -101,7 +101,9 @@ const SYSTEM_DATA_TYPES_VALUES = Object.values(SYSTEM_DATA_TYPES);
 
 export const GENERAL_IMPORTABLE_DATA_TYPES = [
   ...REFERENCE_TYPE_VALUES,
-  ...OTHER_REFERENCE_TYPE_VALUES,
+  ...OTHER_REFERENCE_TYPE_VALUES.filter(
+    (x) => x !== OTHER_REFERENCE_TYPES.PROGRAM_REGISTRY_CLINICAL_STATUS,
+  ),
   ...CLINICAL_DATA_TYPES_VALUES,
   ...SYSTEM_DATA_TYPES_VALUES,
 ].sort();
